aboutsummaryrefslogtreecommitdiffstats
path: root/src/ui/widgets/PlainTextEditorPage.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/ui/widgets/PlainTextEditorPage.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/ui/widgets/PlainTextEditorPage.h b/src/ui/widgets/PlainTextEditorPage.h
index f73e2282..e76c11e3 100644
--- a/src/ui/widgets/PlainTextEditorPage.h
+++ b/src/ui/widgets/PlainTextEditorPage.h
@@ -46,10 +46,10 @@ class PlainTextEditorPage : public QWidget {
/**
* @details Add layout and add plaintextedit
*
* @param filePath Path of the file handled in this tab
* @param parent Pointer to the parent widget
*/
- explicit PlainTextEditorPage(QString filePath = "",
+ explicit PlainTextEditorPage(QString file_path = "",
QWidget* parent = nullptr);
/**
@@ -46,10 +46,10 @@ class PlainTextEditorPage : public QWidget {
* @details Add layout and add plaintextedit
*
- * @param filePath Path of the file handled in this tab
+ * @param file_path Path of the file handled in this tab
* @param parent Pointer to the parent widget
*/